==> chartis-0.0.1.tar.gz: chartis-0.0.1/chartis/__about__.py <==
ascii_chartis_logo = """
                                                .##,
                                               /####(.
                                              /########/.
                                              ###########(.
                                             /##############(,
                                            ,#################(*
                                           .######################,
                                           (########################/.
                                          /############################/.
                                          ###############################(.
                                         /##################################(,
                                        ,#####################################(*
                                       .##########################################,
                                       (############################################/.
                                      /################################################/
                                      ###################################################(.
                                     /######################################################(,
                                    ,#########################################################(*
                                   .##############################################################,
                                   (################################################################/.
                                  /######################%&&%##########################################/
                                  #####################%&&&%%%###########################################(.
                                 /##################%&&&&&%%%%##############################################(,
                                ,################%&&&&&&&&%%%%%###############################################(*
                               .##############%%%%&&&&&@@%%%%%%%##################################################,
                               (############%%%%%%%%%&&@&%%%%%%%####################################################/.
                              /##########%%%%%%%%%%%%%%%%%%%%%%%%######################################################/
                              ########%%%%%%%%%%%%%%%%%%%%%%%%%%%%#######################################################(.
                             /#####%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%##########################################################(,
                            ,####%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%###########################################################(,
                           .##%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%###############################################################,
                           ,#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%#/,..................,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,.
                              ./#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%#/
                                 .(%%%%%%%%%%%%%%%%%%%%%%%%%%(.
                                     ,#%%%%%%%%%%%%%%%%%%#*
                                        *#%%%%%%%%%%%%%(.
                                           ,(%%%%%%#/.
                                              *#%#.
"""

__title__ = "chartis"
__description__ = "Useful things for Airflow."
__url__ = "http://python-requests.org"
__author__ = "Trey Hatch"
__author_email__ = "trey@newmathdata.com"
__license__ = "MIT"
__copyright__ = "Copyright 2019 New Math Data"

==> chartis-0.0.2.tar.gz: chartis-0.0.2/chartis/__about__.py <==
ascii_chartis_logo = """
                                                .##,
                                               /####(.
                                              /########/.
                                              ###########(.
                                             /##############(,
                                            ,#################(*
                                           .######################,
                                           (########################/.
                                          /############################/.
                                          ###############################(.
                                         /##################################(,
                                        ,#####################################(*
                                       .##########################################,
                                       (############################################/.
                                      /################################################/
                                      ###################################################(.
                                     /######################################################(,
                                    ,#########################################################(*
                                   .##############################################################,
                                   (################################################################/.
                                  /######################%&&%##########################################/
                                  #####################%&&&%%%###########################################(.
                                 /##################%&&&&&%%%%##############################################(,
                                ,################%&&&&&&&&%%%%%###############################################(*
                               .##############%%%%&&&&&@@%%%%%%%##################################################,
                               (############%%%%%%%%%&&@&%%%%%%%####################################################/.
                              /##########%%%%%%%%%%%%%%%%%%%%%%%%######################################################/
                              ########%%%%%%%%%%%%%%%%%%%%%%%%%%%%#######################################################(.
                             /#####%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%##########################################################(,
                            ,####%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%###########################################################(,
                           .##%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%###############################################################,
                           ,#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%#/,..................,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,.
                              ./#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%#/
                                 .(%%%%%%%%%%%%%%%%%%%%%%%%%%(.
                                     ,#%%%%%%%%%%%%%%%%%%#*
                                        *#%%%%%%%%%%%%%(.
                                           ,(%%%%%%#/.
                                              *#%#.
"""

__title__ = "chartis"
__description__ = "Useful things for Airflow."
__url__ = "http://github.com/trejas/chartis"
__author__ = "Trey Hatch"
__author_email__ = "trey@newmathdata.com"
__license__ = "MIT"
__copyright__ = "Copyright 2019 New Math Data"
